params_example_1: Parameter list example as provided by a datatable.

Description Usage Format

Description

A named list as processed by a funcFilter. This example results from viewing the first page of a datatable, after ordering the first two columns.

Usage

1

Format

A list with 7 elements:

draw

chr integer, draw counter

start

char integer of first visible record on page (indexed from zero)

length

char integer of page size, e.g. default is 10 records per page

escape

char control html escaping, e.g. "true". See renderDT escape parameter

columns

unnamed list containing one named list item per column

order

unnamed list containing one named list item per sorted column

search

named list with the search $value and other search options


grahamrp/dtdatasources documentation built on Dec. 8, 2019, 12:38 p.m.