A named list as processed by a funcFilter. This example results from
viewing the first page of a datatable, after ordering the first two columns.
1 |
A list with 7 elements:
chr integer, draw counter
char integer of first visible record on page (indexed from zero)
char integer of page size, e.g. default is 10 records per page
char control html escaping, e.g. "true". See renderDT escape parameter
unnamed list containing one named list item per column
unnamed list containing one named list item per sorted column
named list with the search $value and other search options
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.